require 'httparty'
require 'json'

require 'event_registry_api/client/concepts'
require 'event_registry_api/client/events'

module EventRegistryApi
  class Client
    extend EventRegistryApi::Client::Concepts
    extend EventRegistryApi::Client::Events

    API_BASE_URL = "http://eventregistry.org"

    class << self

      private

      ##
      # Convenience method to call get on API.
      # @param {String}
      # @param {Hash}
      # @return {Hash}
      #
      def _get (path, params)
        response = HTTParty.get("#{ API_BASE_URL }#{ path }?#{ _query_string(params) }")

        JSON.parse(response) rescue nil
      end

      ##
      # Need to remove the array feature of to_query to key[]=value.
      # @param {Hash}
      # @return {String}
      #
      def _query_string (hash)
        return nil unless hash.present?

        string = hash.to_query
        string.gsub("[]", "")
      end
    end
  end
end
